Barcode class
Represents a single recognized barcode and its value.
Constructors
-
Barcode({CalendarEvent? calendarEvent, ContactInfo? contactInfo, List<
Offset> corners = const <Offset>[], String? displayValue, DriverLicense? driverLicense, Email? email, BarcodeFormat format = BarcodeFormat.unknown, GeoPoint? geoPoint, Phone? phone, @Deprecated('Use rawDecodedBytes instead.') Uint8List? rawBytes, BarcodeBytes? rawDecodedBytes, String? rawValue, Size size = Size.zero, SMS? sms, BarcodeType type = BarcodeType.unknown, UrlBookmark? url, WiFi? wifi}) -
Creates a new Barcode instance.
const
-
Barcode.fromNative(Map<
Object?, Object?> data) -
Creates a new Barcode instance from the given
data.factory
Properties
- calendarEvent → CalendarEvent?
-
The calendar event that is embedded in the barcode.
final
- contactInfo → ContactInfo?
-
The contact information that is embedded in the barcode.
final
-
corners
→ List<
Offset> -
The corner points of the barcode, relative to the size of the barcode.
final
- displayValue → String?
-
The barcode value in a user-friendly format.
final
- driverLicense → DriverLicense?
-
The driver license information that is embedded in the barcode.
final
- email → Email?
-
The email message that is embedded in the barcode.
final
- format → BarcodeFormat
-
The format of the barcode.
final
- geoPoint → GeoPoint?
-
The geographic point that is embedded in the barcode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phone → Phone?
-
The phone number that is embedded in the barcode.
final
- rawBytes → Uint8List?
-
The raw bytes of the barcode.
final
- rawDecodedBytes → BarcodeBytes?
-
The decoded raw bytes of the barcode.
final
- rawValue → String?
-
The raw string value of the barcode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
The normalized size of the barcode bounding box,
relative to the BarcodeCapture.size of the original barcode capture.
final
- sms → SMS?
-
The SMS message that is embedded in the barcode.
final
- type → BarcodeType
-
The contextual type of the format of the barcode.
final
- url → UrlBookmark?
-
The URL bookmark that is embedded in the barcode.
final
- wifi → WiFi?
-
The Wireless network information that is embedded in the barcode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scaleCorners(
Size targetSize) → List< Offset> -
Scale the corners of this Barcode to the given
targetSize. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited